@@ -1,6 +1,7 @@
 """
 Container for object classes used in cs18-api-client
 """
+import abc
 
 import dateutil.parser
 
@@ -42,12 +43,34 @@ class BlueprintRepositoryDetails:
         self.branch = branch
 
 
-class AddAccountBlueprintRepositoryRequest:
-    def __init__(self, name: str, repository_url: str, access_token: str, repository_type: str, allow_sharing: bool,
+class AddAccountBlueprintRepositoryRequest(abc.ABC):
+    def __init__(self, name: str, repository_url: str, allow_sharing: bool,
                  open_access: bool):
         self.name = name
         self.repository_url = repository_url
-        self.repository_type = repository_type
-        self.access_token = access_token
         self.open_access = open_access
         self.allow_sharing = allow_sharing
+
+
+class AddBlueprintUsingTokenRepositoryRequest(AddAccountBlueprintRepositoryRequest):
+    def __init__(self, name: str, repository_url: str, allow_sharing: bool,
+                 open_access: bool, access_token: str, repository_type: str):
+        super().__init__(name, repository_url, allow_sharing, open_access)
+        self.repository_type = repository_type
+        self.access_token = access_token
+
+
+class AddBlueprintGithubRepositoryRequest(AddAccountBlueprintRepositoryRequest):
+    def __init__(self, name: str, repository_url: str, allow_sharing: bool,
+                 open_access: bool, code: str, state: str):
+        super().__init__(name, repository_url, allow_sharing, open_access)
+        self.code = code
+        self.state = state
+
+
+class AddBlueprintBitbucketRepositoryRequest(AddAccountBlueprintRepositoryRequest):
+    def __init__(self, name: str, repository_url: str, allow_sharing: bool,
+                 open_access: bool, code: str, redirection_url: str):
+        super().__init__(name, repository_url, allow_sharing, open_access)
+        self.code = code
+        self.redirection_url = redirection_url
