@@ -44,7 +44,7 @@ from gateways.common.cs18_api_responses import (
     LaunchingProgress, LaunchingProgressStep, CloudAccountInSpaceResponse, CloudAccountConnectivityResponse,
     CloudAccountInfraSetResponse, CloudAccountSubnetsResponse, RegionResponse, GetImagesResponse,
     VerifyCloudProviderResponse, VerifyCloudProviderResourceResponse, AccountRepositoryResponse,
-    BlueprintValidationResponse, BlueprintValidationSourceResponse, CloudAccountCostResponse,
+    BlueprintValidationResponse, BlueprintSourceResponse, CloudAccountCostResponse,
     ComputeServiceInAccountResponse, ComputeServiceInSpaceResponse, ComputeServiceSpaceSpecResponse,
     K8SComputeServiceSpaceInfraSettingsResponse, BlueprintComputeServiceResponse)
 
@@ -155,10 +155,10 @@ class Converters:
         )
 
     @staticmethod
-    def create_blueprint_validation_source_response(source: dict) -> Optional[BlueprintValidationSourceResponse]:
+    def create_blueprint_validation_source_response(source: dict) -> Optional[BlueprintSourceResponse]:
         if not source:
             return None
-        return BlueprintValidationSourceResponse(
+        return BlueprintSourceResponse(
             branch=source.get("branch"),
             commit=source.get("commit")
         )
@@ -386,7 +386,8 @@ class Converters:
             end_time=dateutil.parser.parse(sandbox["end_time"])
             if sandbox.get("end_time", None) else None,
             debugging_service=sandbox.get('debugging_service'),
-            launching_progress=Converters._create_launching_progress(sandbox.get('launching_progress'))
+            launching_progress=Converters._create_launching_progress(sandbox.get('launching_progress')),
+            source=Converters._create_source(sandbox.get('source'))
         )
 
     @staticmethod
@@ -489,6 +490,12 @@ class Converters:
             message=sandbox_error["message"],
         )
 
+    @staticmethod
+    def _create_source(source: dict) -> Optional[BlueprintSourceResponse]:
+        if not source:
+            return None
+        return BlueprintSourceResponse(branch=source.get('branch'), commit=source.get('commit'))
+
     @staticmethod
     def create_sandbox_response_list_item(sandbox: dict) -> SandboxResponseLean:
         """
@@ -529,9 +536,10 @@ class Converters:
             scheduled_end_time=dateutil.parser.parse(sandbox["scheduled_end_time"]) if sandbox.get(
                 "scheduled_end_time") else None,
             end_time=dateutil.parser.parse(sandbox["end_time"]) if sandbox.get("end_time") else None,
-            debugging_service=sandbox.get("debugging_service")
+            debugging_service=sandbox.get("debugging_service"),
+            source=Converters._create_source(sandbox.get('source'))
         )
-
+ 
     @staticmethod
     def create_production_response_list_item(
             production: dict
